<?php


class Location_Geocentric_Shortcodes {

    /**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

    /**
     * Configuration
     */

    private $headingFontSize;
    private $headingFontColor;
    private $paragraphFontColor;
    private $paragraphFontSize;
    private $neighborhood_limit = 60;
    private $neighborhood_location;
    private $neighborhood_sort;
    private $activities_limit;
    private $activities_location;
    private $activities_sort;
    private $activities_types;
    private $location_sentence;
    private $gmap_zoom;
    private $gmap_height;
    private $gmap_location;
    private $apiKey;
    private $activities_radius = 8;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
        $options = get_option( 'rankfortress_options' );
		$this->version = $version;
        $this->headingFontSize = $options['rankfortress_heading_font_size'];
        $this->headingFontColor = $options['rankfortress_heading_font_color'];
        $this->paragraphFontColor = $options['rankfortress_paragraph_font_color'];
        $this->paragraphFontSize = $options['rankfortress_paragraph_font_size'];
        $this->margin_bottom = $options['rankfortress_margin_bottom'];
        $this->headling_alignment = $options['rankfortress_heading_alignment'];

        $settingsOptions = get_option( 'rankfortress_settings' );
        $this->neighborhood_limit = $settingsOptions['rankfortress_neighborhood_limit'];
        $this->neighborhood_location = $settingsOptions['rankfortress_neighborhood_location'];
        $this->neighborhood_sort = $settingsOptions['rankfortress_neighborhood_sort'];

        $this->activities_limit = $settingsOptions['rankfortress_activities_limit'];
        $this->activities_location = $settingsOptions['rankfortress_activities_location'];
        $this->activities_sort = $settingsOptions['rankfortress_activities_sort'];
        $this->activities_types = $settingsOptions['rankfortress_activities_types'];
        $this->activities_radius = $settingsOptions['rankfortress_activities_radius'];

        $this->location_sentence = $settingsOptions['rankfortress_locations_sentence'];
        $this->gmap_zoom = $settingsOptions['rankfortress_gmap_radius'];
        $this->gmap_height = $settingsOptions['rankfortress_gmap_height'];
        $this->gmap_location = $settingsOptions['rankfortress_gmap_location'];
        $this->apiKey = $settingsOptions['rankfortress_gmap_api'];

	}

    public function about_location( $atts, $content= null, $code = '' )
    {

        ob_start();
        
        $atts = shortcode_atts(
			array(
				'title' => '',
				'location' => '',
                'limit' => ($this->location_sentence !== '')? $this->location_sentence : 10
			),
			$atts, 'rankfortress'
		);
        
        
        $args = array(
            'title' => trim( $atts['title'] ),
            'location' => trim( $atts['location'] ),
            'limit' =>  trim( $atts['limit'] )
        );

        $this->about_location_html($args);

        return ob_get_clean();
    }

    public function neighborhood( $atts, $content= null, $code = '' )
    {

        ob_start();
        
        $atts = shortcode_atts(
			array(
				'title' => '',
				'location' => $this->neighborhood_location,
                'limit' => $this->neighborhood_limit,
                'sort' => $this->neighborhood_sort
			),
			$atts, 'rankfortress'
		);
        
        $args = array(
            'title' => trim( $atts['title'] ),
            'location' => trim( $atts['location'] ),
            'limit' =>  trim( $atts['limit'] ),
            'sort' =>  trim( strtolower($atts['sort']) )
        );

        $this->neighborhood_html($args);

        return ob_get_clean();
    }

    public function activities( $atts, $content= null, $code = '' )
    {
        ob_start();

        $atts = shortcode_atts(
			array(
				'title' => '',
				'location' => $this->activities_location,
                'limit' => $this->activities_limit,
                'sort' => $this->activities_sort,
                'types' => $this->activities_types,
                'radius' => $this->activities_radius
			),
			$atts, 'rankfortress'
		);
        
        $args = array(
            'title' => trim( $atts['title'] ),
            'location' => trim( $atts['location'] ),
            'limit' =>  trim( $atts['limit'] ),
            'sort' =>  trim( strtolower($atts['sort']) ),
            'types' =>  trim( strtolower($atts['types']) ),
            'radius' =>  trim( strtolower($atts['radius']) )
        );

        $this->activities_html($args);

        return ob_get_clean();
    }

    public function map( $atts, $content= null, $code = '' )
    {

        ob_start();
        
        $atts = shortcode_atts(
			array(
				'title' => '',
				'location' => $this->gmap_location,
                'zoom' => ($this->gmap_zoom !== '')? $this->gmap_zoom : 8,
                'neighborhood' => '',
                'activities' => ''
			),
			$atts, 'rankfortress'
		);
        
        $args = array(
            'title' => trim( $atts['title'] ),
            'location' => trim( $atts['location'] ),
            'zoom' => trim( $atts['zoom'] ),
            'neighborhood' => trim( $atts['neighborhood'] ),
            'activities' => trim( $atts['activities'] )
        );

        $this->map_html($args);

        return ob_get_clean();
    }

    public function directions( $atts, $content= null, $code = '' )
    {

        ob_start();
        
        $atts = shortcode_atts(
			array(
				'title' => '',
				'address' => '',
                'zoom' => 8,
                'pins' => 5,
                'city' => ''
			),
			$atts, 'rankfortress'
		);
        
        $args = array(
            'title' => trim( $atts['title'] ),
            'address' => trim( $atts['address'] ),
            'zoom' => trim( $atts['zoom'] ),
            'city' => trim( $atts['city'] ),
            'pins' => trim( $atts['pins'] )
        );

        $this->directions_html($args);

        return ob_get_clean();
    }

    public function reviews( $atts, $content= null, $code = '' )
    {

        ob_start();
        
        $atts = shortcode_atts(
			array(
				'place_id' => '',
                'latlng' => ''
			),
			$atts, 'rankfortress'
		);
        
        $args = array(
            'place_id' => trim( $atts['place_id'] ),
            'latlng' => trim( $atts['latlng'] )
        );

        $this->reviews_html($args);

        return ob_get_clean();
    }
    
    public function neighborhood_html($args)
    {
        
        $dataLocation = (isset($args['location']) && $args['location'] !== '')? 'data-location="'.$args['location'].'"' : '';
        $dataLimit = (isset($args['limit']) && $args['limit'] !== '')? 'data-limit="'.$args['limit'].'"' : '';
        $dataSort = (isset($args['sort']) && $args['sort'] !== '')? 'data-sort="'.$args['sort'].'"' : '';
        $dataAttributes = $dataLocation . ' ' . $dataLimit . ' '. $dataSort;
        
        $title = ($args['title'] !== '')? $args['title'] : 'Neighborhood';

        if( isset($args['location']) && $args['location'] !== '' ):
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block rkfrt-neighborhoods js-rkfrt-neighborhoods" '.$dataAttributes.'  data-id="rkfrtd-neighborhood-'.substr(bin2hex($args['location']), 0, 20).'">';
            $this->getGifLoader();
            echo '<div class="rkfrt-block__area rkfrt-block--loading">';
            echo '<div class="rkfrt-gmap" style="width:100%; height: 500px;"></div>';
            echo '<div>';
            $this->getTitle($title);
            echo '<p class="rkfrt-neighborhoods js-rkfrt-list" style="font-size:'.$this->paragraphFontSize.'px; color:'.$this->paragraphFontColor.';"></p>';
            echo '</div>';
            echo '</div>';
            echo '</div>';
        endif;
        
    }

    public function activities_html($args){

        $dataLocation = (isset($args['location']) && $args['location'] !== '')? 'data-location="'.$args['location'].'"' : '';
        $dataLimit = (isset($args['limit']) && $args['limit'] !== '')? 'data-limit="'.$args['limit'].'"' : '';
        $dataRadius = (isset($args['radius']) && $args['radius'] !== '')? 'data-radius="'.$args['radius'].'"' : '';
        $dataSort = (isset($args['sort']) && $args['sort'] !== '')? 'data-sort="'.$args['sort'].'"' : '';
        $dataTypes = (isset($args['types']) && $args['types'] !== '')? 'data-types="'.$args['types'].'"' : '';
        $dataAttributes = $dataLocation . ' ' . $dataLimit . ' '. $dataSort . ' ' . $dataTypes . ' ' . $dataRadius;
        $title = ($args['title'] !== '')? $args['title'] : 'Neighborhood';

        if( isset($args['location']) && $args['location'] !== '' ):
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block rkfrt-activities js-rkfrt-activities"   '.$dataAttributes.' data-id="rkfrtd-activities-'.substr(bin2hex($args['location']), 0, 20).'">';
            $this->getGifLoader();
            echo '<div class="rkfrt-block__area rkfrt-block--loading">';
            echo '<div class="rkfrt-gmap"  style="display: none;"></div>';
            echo '<div>';
            $this->getTitle($title);
            
            echo '<div class="rkfrt__list js-rkfrt-list"></div>';
            echo '</div>';
            echo '</div>';
            echo '</div>';
        endif;

    }

    public function map_html($args){
        
        $dataLocation = (isset($args['location']) && $args['location'] !== '')? 'data-location="'.$args['location'].'"' : '';
        $dataZoom = (isset($args['zoom']) && $args['zoom'] !== '')? 'data-zoom="'.$args['zoom'].'"' : '';
        $dataNeighborhood = (isset($args['neighborhood']) && $args['neighborhood'] !== '')? 'data-neighborhood="'.$args['neighborhood'].'"' : '';
        $dataActivities = (isset($args['activities']) && $args['activities'] !== '')? 'data-activities="'.$args['activities'].'"' : '';
        $dataAttributes = $dataLocation . ' ' . $dataZoom . ' ' . $dataNeighborhood . ' ' . $dataActivities;
        $title = ($args['title'] !== '')? $args['title'] : 'Google Map';
        $mapHeight = 'height: ' . $this->gmap_height . 'px;';

        if( isset($args['location']) && $args['location'] !== '' ):
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block rkfrt-map js-rkfrt-map"  '.$dataAttributes.'>';
            $this->getGifLoader();
            echo '<div class="rkfrt-block__area rkfrt-block--loading">';
            $this->getTitle($title);
            echo '<div id="rkfrt-map" class="rkfrt-gmap" '.$this->addBlockStyle($mapHeight).'></div>';
            echo '</div>';
            echo '</div>';
        endif;
    }

    public function about_location_html($args){

        $dataLocation = (isset($args['location']) && $args['location'] !== '')? 'data-location="'.$args['location'].'"' : '';
        $dataLimit = (isset($args['limit']) && $args['limit'] !== '')? 'data-limit="'.$args['limit'].'"' : '';
        $dataAttributes = $dataLocation . ' ' . $dataLimit;
        $title = ($args['title'] !== '')? $args['title'] : $args['location'];
        $classes = 'rkfrt-mb-0';
       
        if( isset($args['location']) && $args['location'] !== '' ): 
            
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block rkfrt-aboutlocation js-rkfrt-aboutlocation"  '.$dataAttributes.' data-id="rkfrtd-details-'.substr(bin2hex($args['location']), 0, 20).'">';
            $this->getGifLoader();
            echo '<div class="rkfrt-block__area rkfrt-block--loading">';
            echo '<div><div class="rkfrt-aboutlocation__header text-'.$this->headling_alignment.'">';

            $this->getTitle($title, $classes);
            echo '<p class="rkfrt-gray">City of '.$args['location'].'</p>';
            echo '</div>';
            echo '<div class="rkfrt-desc js-rkfrt-desc" style="font-size: '.$this->paragraphFontSize.'px;"></div>';
            echo '<ul class="rkfrt-ul">';
            echo '<li><strong>Area:</strong> <span class="js-rkfrt-area">' . $this->getGifDualLoader(). '</span></li>';
            echo '<li><strong>Local Time:</strong> <span class="js-rkfrt-timezone">' . $this->getGifDualLoader(). '</span></li>';
            echo '<li><strong>Mayor:</strong> <span class="js-rkfrt-mayor">' . $this->getGifDualLoader(). '</span></li>';
            echo '<li><strong>Weather:</strong> <span class="js-rkfrt-weather">' . $this->getGifDualLoader(). '</span></li>';
            echo '<li><strong>Population:</strong> <span class="js-rkfrt-population">' . $this->getGifDualLoader(). '</span></li>';
            echo '</ul>';
            echo '</div>';
            echo '</div>';
            echo '</div>';
        endif;

    }

    public function directions_html($args){

        global $post;
        $current_id = $post->ID;
        
        $dataLocation = (isset($args['address']) && $args['address'] !== '')? 'data-address="'.$args['address'].'"' : '';
        $dataZoom = (isset($args['zoom']) && $args['zoom'] !== '')? 'data-zoom="'.$args['zoom'].'"' : '';
        $dataCity = (isset($args['city']) && $args['city'] !== '')? 'data-city="'.$args['city'].'"' : '';
        $dataPins = (isset($args['pins']) && $args['pins'] !== '')? 'data-pins="'.$args['pins'].'"' : '';
        $dataAttributes = $dataLocation . ' ' . $dataZoom . ' ' . $dataCity . ' ' . $dataPins;
        
        $title = ($args['title'] !== '')? $args['title'] : 'Google Map';
        $mapHeight = 'height: ' . $this->gmap_height . 'px;';

        if( isset($args['address']) && $args['address'] !== '' && isset($args['city']) && $args['city'] !== '' ):
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block js-rkfrt-directions"  '.$dataAttributes.' data-id="rkfrtd-'.substr(bin2hex($args['address']), 0, 20).'">';
            $this->getGifLoader();
            echo '<div class="rkfrt-block__area rkfrt-block--loading">';
            $this->getTitle($title);
            
            echo '<div class="rkfrt-directions__area rkfrt-directions ">';
            echo '<div class="rkfrt-directions__sidebar js-rkfrt-directions-sidebar">';
            echo '<ul id="js-rkfrt-direction-routes" class="rkfrt-directions__routes"></ul>';
            echo '<button class="js-clear-routes btn-clear-routes">Clear all routes</button>';
            echo '</div>';
            echo '<div class="rkfrt-directions__content">';
            echo '<div id="rkfrt-directions-map" style="width:100%;height:100%"></div>';
            echo '<div id="rkfrt-directions-map2" style="display: none;width:100%;height:100%"></div>';
            echo '</div>';
            echo '</div>';

            echo '</div>';
            echo '</div>';
        else :
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block js-rkfrt-directions" >';
            echo 'Please add the location address and city.';
            echo '</div>';
        endif;
    }

    public function reviews_html($args){
        
        $dataPlaceId = (isset($args['place_id']) && $args['place_id'] !== '')? 'data-place-id="'.$args['place_id'].'"' : '';
        $dataLatlng = (isset($args['latlng']) && $args['latlng'] !== '')? 'data-latlng="'.$args['latlng'].'"' : '';
        $dataAttributes = $dataPlaceId . ' ' . $dataLatlng;

        if( isset($args['place_id']) && $args['place_id'] !== '' ):
            echo '<div '.$this->addBlockStyle().' class="rkfrt-block rkfrt-reviews js-rkfrt-reviews"  '.$dataAttributes.'>';
            $this->getGifLoader();
            echo '<div class="rkfrt-gmap" id="rkfrt-map-reviews" style="display:none;"></div>';
            echo '<div class="rkfrt-block__area js-rkfrt-reviews-area rkfrt-block--loading">';
            echo '<div class="rkfrt-reviews-cards js-rkfrt-reviews-cards"></div>';
            echo '</div>';
            echo '</div>';
        endif;
    }

    public function addBlockStyle( $styles = null ){

        $properties = '';

        $properties .= 'margin-bottom:' . $this->margin_bottom . 'px;';

        $properties .= $styles;

        return ' style="'.$properties.'"' ;
    }

    public function getTitle($title, $cssClasses = '') {
        echo '<h2 class="rkfrt__title '.$cssClasses.' text-'.$this->headling_alignment.'" style="font-size:'.$this->headingFontSize.'px; color:'.$this->headingFontColor.'">'.$title.'</h2>';
    }

    public function getGifLoader() {
        echo '<div class="rkfrt-loader js-rkfrt-loader"><img src="' . esc_url( plugins_url( 'public/img/rf-loader.gif', dirname(__FILE__) ) ) . '" /></div>';
    }

    public function getGifDualLoader() {
        return '<em class="rkfrt-small-loader js-rkfrt-small-loader"><img src="' . esc_url( plugins_url( 'public/img/dual-loader.gif', dirname(__FILE__) ) ) . '" /></em>';
    }
}