<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://rankfortress.com/
 * @since      1.0.0
 *
 * @package    Location_Geocentric
 * @subpackage Location_Geocentric/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Location_Geocentric
 * @subpackage Location_Geocentric/public
 * @author     RankFortress <dwaqaddi@gmail.com>
 */
class Location_Geocentric_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

    private $apiKey = 'AIzaSyALst4KZXiEiUNL66XkCajtTyfgebVyAA8';
    private $openweatherKey;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

        $settingsOptions = get_option( 'rankfortress_settings' );

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        $this->apiKey = $settingsOptions['rankfortress_gmap_api'];
        $this->openweatherKey = $settingsOptions['rankfortress_ow_api'];

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Location_Geocentric_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Location_Geocentric_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/public.css', array(), rand(1, 100), 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Location_Geocentric_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Location_Geocentric_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

        wp_enqueue_script( $this->plugin_name . '-gmap', 'https://maps.googleapis.com/maps/api/js?key='.$this->apiKey.'&libraries=places', array(), false, true );
        wp_enqueue_script( $this->plugin_name . '-cluster', 'https://unpkg.com/@googlemaps/markerclustererplus/dist/index.min.js', array(), false, true );
        wp_enqueue_script( $this->plugin_name . '-tz', plugin_dir_url( __FILE__ ) . 'js/vendors/tz.js', array( 'jquery' ), $this->version, true );
        wp_enqueue_script( $this->plugin_name . '-lscache', plugin_dir_url( __FILE__ ) . 'js/vendors/lscache.js', array( 'jquery' ), $this->version, true );
        wp_enqueue_script( $this->plugin_name . '-nicescroll', plugin_dir_url( __FILE__ ) . 'js/vendors/nicescroll.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-places', plugin_dir_url( __FILE__ ) . 'js/public.js', array( 'jquery' ), rand(0,100) , true );
        
    }

    public function header_meta() {
        $openweatherKey = $this->openweatherKey;
        echo "<meta name='rkfrt-map-key' content='".$this->apiKey."' />";

        if( $openweatherKey == '' ){
            $openweatherKey = '';
        }

        echo "<meta name='rkfrt-openweather-key' content='".$openweatherKey."' />";
    }

    

}