// Require path.
const path = require('path');
const autoprefixer = require('autoprefixer');
const cssnano = require('cssnano');
const MiniCssExtractPlugin = require("mini-css-extract-plugin");

// Configuration object.
const config = {

    resolve: {
        extensions: ['.css', '.scss'],
        alias: {
          // Provides ability to include node_modules with ~
          '~': path.resolve(process.cwd(), 'src'),
        },
    },
    
	// Create the entry points.
	// One for frontend and one for the admin area.
	entry: {
		// frontend and admin will replace the [name] portion of the output config below.
        public: ['./src/public/public.js', './src/public/public.scss'],
        admin: ['./src/admin/admin.js', './src/admin/admin.scss']
	},

	// Create the output files.
	// One for each of our entry points.
	output: {
		// [name] allows for the entry object keys to be used as file names.
		filename: '[name]/js/[name].js',
		// Specify the path to the JS files.
		path: path.resolve( __dirname, './' )
	},

	// Setup a loader to transpile down the latest and great JavaScript so older browsers
	// can understand it.
	module: {
		rules: [
			{
				// Look for any .js files.
				test: /\.js$/,
				// Exclude the node_modules folder.
				exclude: /node_modules/,
				// Use babel loader to transpile the JS files.
				loader: 'babel-loader'
            },
            {
                test: /\.scss$/,
                use: [
                  // Extract and save the final CSS.
                  MiniCssExtractPlugin.loader,
                  // Load the CSS, set url = false to prevent following urls to fonts and images.
                  { loader: "css-loader", options: { url: false, importLoaders: 1 } },
                  // Add browser prefixes and minify CSS.
                    { loader: 'postcss-loader', options: { postcssOptions: { plugins: [autoprefixer(), cssnano()] } }},
                  // Load the SCSS/SASS
                  { loader: 'sass-loader' },
                ],
              }
		]
    },
    plugins: [
        // Define the filename pattern for CSS.
        new MiniCssExtractPlugin({
          filename: '[name]/css/[name].css',
          chunkFilename: '[id].css',
        })
      ]
}

// Export the config object.
module.exports = config;